@@ -96,7 +96,8 @@ class Action():
                 parse_mode = None
                 if "parse_mode" in item:
                     parse_mode = item["parse_mode"]
-
+                print("type: ", type(update))
+                print("update: ", update)
                 if type(update) == CallbackQuery:
                     update.from_user.send_message(item["text"].format(
                         **{"echo": update.message.text, "name": context.user_data["name"]}), reply_markup=reply_markup, parse_mode=parse_mode)
@@ -138,6 +139,8 @@ class Action():
                     update.poll_answer.user.send_sticker(item["id"])
                 else:
                     update.message.reply_sticker(item["id"])
+            elif item["type"] == "video":
+                update.message.reply_video(open(item["file"], 'rb'))
             
             ## type: venue
             # latitude: 52.4090401
